set -e

cmd=read.py

export PYTHONPATH=../../

cacheTopDir=/tmp/hakmatak-$USER/cache
